{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template tiny_aiplacement/imagemodal

    Modal to manage AI generated image content within the Tiny Editor.

    Classes required for JS:
    * none

    Data attributes required for JS:
    * none

    Context variables required for this template:
    * elementid: The id of the element that will be used to create the modal.

    Example context (json):
    {
        "elementid": "exampleId"
    }
}}
{{< core/modal }}

  {{$title}}
    {{#str}} imagemodaltitle, tiny_aiplacement{{/str}}
  {{/title}}

  {{$body}}
    {{> tiny_aiplacement/loading }}
    {{> tiny_aiplacement/modalbodyimage }}
  {{/body}}

  {{$footer}}
    {{> tiny_aiplacement/modalfooterimage }}
  {{/footer}}

{{/ core/modal }}
