{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template tiny_aiplacement/modalbodytext

    Modal to manage AI generated text content within the Tiny Editor.

    Classes required for JS:
    * none

    Data attributes required for JS:
    * none

    Context variables required for this template:
    * elementid: The id of the element that will be used to create the modal.

    Example context (json):
    {
        "elementid": "exampleId"
    }
}}
<div id="{{elementid}}_tiny_aiplacement_blur">
    <div id="{{elementid}}_tiny_aiplacement_overlay" class="tiny-aiplacement-overlay hidden"></div>
    <div class="container">
        <div class="row justify-content-md-center">
            <div class="col-md-4">
                <label for="{{elementid}}_tiny_aiplacement_textprompt" class="fw-bold">
                    {{#str}} textprompt_label, tiny_aiplacement {{/str}}
                </label>
                <textarea
                        class="form-control"
                        id="{{elementid}}_tiny_aiplacement_textprompt"
                        autocomplete="off"
                        rows="12"></textarea>
            </div>
            <div class="col-md-8">
                <div id="{{elementid}}_tiny_aiplacement_generate_text" class="tiny-aiplacement-generate-text text-center mt-3 mt-lg-0">
                    <div class="tiny-aiplacement-fa-text"></div>
                </div>
            </div>
        </div>
    </div>
</div>
