{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template tiny_aiplacement/modalbodyerror

    Display the error for Tiny AI placement.

    Classes required for JS:
    * none

    Data attributes required for JS:
    * none

    Context variables required for this template:
    * none

    Example context (json):
    {
        "errorMessage": "ABC"
    }
}}
<div class="d-flex align-items-center h-100">
    <div class="tiny-aiplacement-error-display w-50" role="alert">
        <div class="fw-bold">
            <i class="icon fa fa-info-circle m-0 text-danger" aria-hidden="true"></i>
            <span class="d-inline-block">
                {{#str}} generatefailtitle, tiny_aiplacement{{/str}}
            </span>
        </div>
        <div>
            {{errorMessage}}
        </div>
    </div>
</div>
