.tiny-aiplacement-overlay {
    position: absolute;
    background: rgba(255, 255, 255, 1);
    top: 0;
    bottom: 0;
    right: 0;
    left: 0;
    z-index: 2;
}

.tiny-aiplacement-blur {
    filter: blur(4px);
}

.tiny-aiplacement-loading-spinner-container {
    min-height: 300px;
}

.tiny-aiplacement-loading-spinner {
    position: absolute;
    top: 0;
    bottom: 0;
    right: 0;
    left: 0;
    display: flex;
    align-items: center;
    justify-content: center;
}

.tiny-aiplacement-spinner-style {
    width: 3rem !important; /* stylelint-disable-line declaration-no-important */
    height: 3rem !important; /* stylelint-disable-line declaration-no-important */
    color: #0f6cbf;
    z-index: 1000;
}

.tiny-aiplacement-spinner-text-style {
    font-size: 1.5rem;
    font-weight: bold;
    z-index: 1000;
}

.tiny-aiplacement-generate-image,
.tiny-aiplacement-generate-text {
    border-radius: 15px;
    border: 2px dashed #bbb;
    padding: 20px;
    display: flex;
    flex-direction: column;
    justify-content: center;
    align-items: center;
    height: 100%;
    min-height: 150px;
    margin-left: 0;
    margin-top: 0;
}

.tiny-aiplacement-generate-text textarea:disabled {
    background-color: unset;
}

.tiny_aiplacement_modal {
    min-height: 30em;
}

.tiny-aiplacement-fa-image {
    height: 100%;
    width: 100%;
    background-image: url('[[pix:tiny_aiplacement|sparkles-image]]');
    background-repeat: no-repeat;
    background-position: center;
    background-color: rgba(255, 255, 255, 0.5);
    background-blend-mode: lighten;
    background-size: 100px 100px;
}

.tiny-aiplacement-toggle-container {
    position: relative;
    width: 100%;
    display: flex;
    justify-content: center;
    align-items: center;
}
.tiny-aiplacement-toggle-switch {
    display: none;
}
.tiny-aiplacement-toggle-slider {
    width: 100%;
    display: flex;
    justify-content: space-between;
    align-items: center;
    background-color: #fff;
    border-radius: 34px;
    padding: 2px;
    border: 1px solid #aaa;
}
.tiny-aiplacement-toggle-slider span {
    width: 50%;
    text-align: center;
    padding: 5px 0;
    border-radius: 34px;
    cursor: pointer;
    transition: background-color 0.3s, color 0.3s;
}
.tiny-aiplacement-toggle-switch:checked + .tiny-aiplacement-toggle-slider .tiny-aiplacement-slider-right {
    background-color: #007bff;
    color: white;
}
.tiny-aiplacement-toggle-switch:not(:checked) + .tiny-aiplacement-toggle-slider .tiny-aiplacement-slider-left {
    background-color: #007bff;
    color: white;
}

.tiny-aiplacement-aspect-ratio-container {
    display: flex;
}
.tiny-aiplacement-aspect-ratio-btn {
    position: relative;
    width: 100px;
    height: 75px;
    background-color: #f8f9fa;
    border-radius: 15px;
    text-align: center;
    cursor: pointer;
    display: flex;
    flex-direction: column;
    justify-content: center;
    align-items: center;
    transition: background-color 0.3s, border-color 0.3s;
}
.tiny-aiplacement-aspect-ratio-btn i {
    font-size: 30px;
    margin-bottom: 5px;
}
.tiny-aiplacement-aspect-ratio-btn span {
    font-size: 14px;
}
.tiny-aiplacement-aspect-ratio-btn input[type="radio"] {
    display: none;
}
.tiny-aiplacement-aspect-ratio-btn input[type="radio"]:checked + .tiny-aiplacement-aspect-ratio-label {
    background-color: #007bff;
    color: white;
    border-color: #007bff;
}
.tiny-aiplacement-aspect-ratio-label {
    width: 100%;
    height: 100%;
    display: flex;
    flex-direction: column;
    justify-content: center;
    align-items: center;
    border-radius: 15px;
    transition: background-color 0.3s, border-color 0.3s;
    border: 1px solid #aaa;
}

.tiny-aiplacement-fa-text {
    height: 100%;
    width: 100%;
    background-image: url('[[pix:tiny_aiplacement|sparkles-text]]');
    background-repeat: no-repeat;
    background-position: center;
    background-color: rgba(255, 255, 255, 0.5);
    background-blend-mode: lighten;
    background-size: 100px 100px;
}

.tiny-aiplacement-generate-footer button img {
    width: 1.5em;
    margin-right: 0.2em;
}

.tiny-aiplacement-error-display {
    margin: 0 auto;
}

.ai-policy-heading {
    font-size: 1.5rem;
    font-weight: bold;
    margin-bottom: 10px;
    color: #0f6cbf;
}

.ai-policy-display {
    font-size: 1.1rem;
    margin-left: 20px;
    margin-right: 20px;
}

.ai-policy-display br {
    line-height: 2.5rem;
}

@media (max-width: 767px) {
    .tiny_aiplacement_textresponse_placeholder {
        min-height: 12em;
        margin-top: 20px;
    }
}
