{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template tiny_aiplacement/loading

    Template for the loading spinner.

    Classes required for JS:
    * none

    Data attributes required for JS:
    * none

    Context variables required for this template:
    * ishidden: Whether the spinner should be hidden or not.

    Example context (json):
    {
        "elementid": "exampleId",
        "ishidden": true
    }
}}
<div id="{{elementid}}_tiny_aiplacement_spinner" class="tiny-aiplacement-loading-spinner-container hidden">
    <div class="tiny-aiplacement-loading-spinner d-flex justify-content-center align-items-center flex-column">
        <div class="spinner-border tiny-aiplacement-spinner-style" aria-hidden="true"></div>
        <div id="{{elementid}}_tiny_aiplacement_loading_text" class="text-center tiny-aiplacement-spinner-text-style" role="status">
            {{#str}} loading, tiny_aiplacement{{/str}}
        </div>
    </div>
</div>
