<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'tiny_aiplacement', language 'en'.
 *
 * @package    tiny_aiplacement
 * @copyright  2024 Matt Porritt <matt.porritt@moodle.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['aiplacement:generateimage'] = 'Generate image using AI';
$string['aiplacement:generatetext'] = 'Generate text using AI';
$string['aspectlandscape'] = 'Landscape';
$string['aspectportrait'] = 'Portrait';
$string['aspectratio'] = 'Image shape';
$string['aspectsquare'] = 'Square';
$string['back'] = 'Go back';
$string['buttontitle'] = 'tester';
$string['definitionhigh'] = 'High';
$string['definitionstandard'] = 'Standard';
$string['errorgeneral'] = 'Try again later';
$string['generate'] = 'Generate';
$string['generatefailtitle'] = 'Something went wrong';
$string['generateimage'] = 'Generate image';
$string['generatetext'] = 'Generate text';
$string['generating'] = 'Generating';
$string['imagemodaltitle'] = 'Generate an image using AI';
$string['imageprompt_label'] = 'Describe the image you want AI to create';
$string['imageprompt_placeholder'] = 'Try \'Mountain landscape\'';
$string['imagequality'] = 'Image quality';
$string['imagestyle'] = 'Image style';
$string['insert'] = 'Insert';
$string['loading'] = 'Loading...';
$string['loading_almostdone'] = 'Almost done...';
$string['loading_applying'] = 'Applying the finishing touches...';
$string['loading_generating'] = 'Generating the response...';
$string['loading_processing'] = 'Processing your request...';
$string['next'] = 'Next';
$string['pluginname'] = 'AI placement';
$string['privacy:metadata'] = 'The AI placement plugin does not store any personal data.';
$string['regenerate'] = 'Regenerate';
$string['textmodaltitle'] = 'Generate text using AI';
$string['textprompt_label'] = 'Describe the text you want AI to create. You can include details like topic, length, audience, or tone.';
$string['textresponse_label'] = 'AI-generated text';
$string['textresponse_placeholder'] = 'Generated text will appear here, and can be edited before inserting into the editor.';
